pub enum DexPoolData {
Swap(PoolSwap),
LiquidityUpdate(PoolLiquidityUpdate),
FeeCollect(PoolFeeCollect),
FeeProtocolUpdate(PoolFeeProtocolUpdate),
FeeProtocolCollect(PoolFeeProtocolCollect),
Flash(PoolFlash),
}Variants
Swap(PoolSwap)
LiquidityUpdate(PoolLiquidityUpdate)
FeeCollect(PoolFeeCollect)
FeeProtocolUpdate(PoolFeeProtocolUpdate)
FeeProtocolCollect(PoolFeeProtocolCollect)
Flash(PoolFlash)
Implementations
Sourceimpl DexPoolData
impl DexPoolData
Sourcepub fn block_number(&self) -> u64
pub fn block_number(&self) -> u64
Returns the block number associated with this pool event.
Sourcepub fn transaction_index(&self) -> u32
pub fn transaction_index(&self) -> u32
Returns the transaction index associated with this pool event.